@@ -1,7 +1,7 @@
 __author__ = 'Altertech, http://www.altertech.com/'
 __copyright__ = 'Copyright (C) 2018-2020 Altertech Group'
 __license__ = 'Apache License 2.0'
-__version__ = '2.0.6'
+__version__ = '2.0.7'
 
 from flask import request, jsonify, Response, abort
 
@@ -32,6 +32,7 @@ from .core import endpoint_delete_subscriptions
 
 from .core import subscription_get, subscription_list, subscription_create
 from .core import subscription_update, subscription_delete
+from .core import cleanup as core_cleanup
 
 from .core import json, is_parse_db_json, delete_everything
 
@@ -489,6 +490,8 @@ def test(**kwargs):
 def r_core_cmd(cmd=None):
     if cmd == 'reset-addr-limits':
         reset_addr_limits()
+    elif cmd == 'cleanup':
+        core_cleanup()
     elif cmd == 'delete-everything':
         delete_everything()
     else:
